    .. _upnp_services_clients_connection_manager_client:

coherence.upnp.services.clients.connection\_manager\_client (module)
--------------------------------------------------------------------

.. automodule:: coherence.upnp.services.clients.connection_manager_client
